@@ -11,13 +11,13 @@ from typing import Type, Union
 import easyutils
 from pywinauto import findwindows, timings
 
-from easytrader import grid_strategies, pop_dialog_handler
+from easytrader import grid_strategies, pop_dialog_handler, refresh_strategies
 from easytrader.config import client
 from easytrader.grid_strategies import IGridStrategy
 from easytrader.log import logger
+from easytrader.refresh_strategies import IRefreshStrategy
 from easytrader.utils.misc import file2dict
 from easytrader.utils.perf import perf_clock
-from win32gui import SetForegroundWindow, ShowWindow
 
 if not sys.platform.startswith("darwin"):
     import pywinauto
@@ -63,6 +63,7 @@ class ClientTrader(IClientTrader):
     # The strategy to use for getting grid data
     grid_strategy: Union[IGridStrategy, Type[IGridStrategy]] = grid_strategies.Copy
     _grid_strategy_instance: IGridStrategy = None
+    refresh_strategy: IRefreshStrategy = refresh_strategies.Switch()
 
     def enable_type_keys_for_editor(self):
         """
@@ -85,14 +86,7 @@ class ClientTrader(IClientTrader):
         self._config = client.create(self.broker_type)
         self._app = None
         self._main = None
-
-    def _set_foreground(self, grid=None):
-        if grid is None:
-            grid = self._trader.main
-        if grid.has_style(pywinauto.win32defines.WS_MINIMIZE):  # if minimized
-            ShowWindow(grid.wrapper_object(), 9)  # restore window state
-        else:
-            SetForegroundWindow(grid.wrapper_object())  # bring to front
+        self._toolbar = None
 
     @property
     def app(self):
@@ -121,6 +115,7 @@ class ClientTrader(IClientTrader):
         self._app = pywinauto.Application().connect(path=connect_path, timeout=10)
         self._close_prompt_windows()
         self._main = self._app.top_window()
+        self._init_toolbar()
 
     @property
     def broker_type(self):
@@ -132,6 +127,9 @@ class ClientTrader(IClientTrader):
 
         return self._get_balance_from_statics()
 
+    def _init_toolbar(self):
+        self._toolbar = self._main.child_window(class_name="ToolbarWindow32")
+
     def _get_balance_from_statics(self):
         result = {}
         for key, control_id in self._config.BALANCE_CONTROL_ID_GROUP.items():
@@ -431,10 +429,6 @@ class ClientTrader(IClientTrader):
             text
         )
 
-    def _type_common_control_keys(self, control, text):
-        self._set_foreground(control)
-        control.type_keys(text, set_foreground=False)
-
     def _type_edit_control_keys(self, control_id, text):
         if not self._editor_need_type_keys:
             self._main.child_window(
@@ -489,7 +483,8 @@ class ClientTrader(IClientTrader):
         ).double_click(coords=(x, y))
 
     def refresh(self):
-        self._switch_left_menus_by_shortcut("{F5}", sleep=0.1)
+        self.refresh_strategy.set_trader(self)
+        self.refresh_strategy.refresh()
 
     @perf_clock
     def _handle_pop_dialogs(self, handler_class=pop_dialog_handler.PopDialogHandler):
@@ -544,3 +539,4 @@ class BaseLoginClientTrader(ClientTrader):
             comm_password,
             **kwargs
         )
+        self._init_toolbar()
